==> haskell-exact-pi-0.5.0.2-63-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-ZjZPO0S9g5HuGWYgaaffg
key:                  exact-pi-0.5.0.2-ZjZPO0S9g5HuGWYgaaffg
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  be67b0b222dd8df6374366bc56975d92
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-ZjZPO0S9g5HuGWYgaaffg
depends:
    base-4.16.4.0 numtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exact-pi-0.5.0.2-92.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-HcllLjdIeD7LB43kqH7Bsr
key:                  exact-pi-0.5.0.2-HcllLjdIeD7LB43kqH7Bsr
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  5ceef56b3f0c2f624d200903b2118c70
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-HcllLjdIeD7LB43kqH7Bsr
depends:
    base-4.17.2.1 numtype-dk-0.5.0.3-F6qEUKEaZatXZetkjwDdM

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
